diff --git a/src/latexdocvisitor.cpp b/src/latexdocvisitor.cpp
index 37c2130..7ff67ff 100644
--- a/src/latexdocvisitor.cpp
+++ b/src/latexdocvisitor.cpp
@@ -408,10 +408,10 @@ void LatexDocVisitor::visit(DocVerbatim *s)
 void LatexDocVisitor::visit(DocAnchor *anc)
 {
   if (m_hide) return;
-  m_t << "\\label{" << stripPath(anc->file()) << "_" << anc->anchor() << "}%" << endl;
+  m_t << "\\label{" << anc->file() << "_" << anc->anchor() << "}%" << endl;
   if (!anc->file().isEmpty() && Config_getBool("PDF_HYPERLINKS")) 
   {
-    m_t << "\\hypertarget{" << stripPath(anc->file()) << "_" << anc->anchor() 
+    m_t << "\\hypertarget{" << anc->file() << "_" << anc->anchor() 
       << "}{}%" << endl;
   }    
 }
@@ -789,11 +789,11 @@ void LatexDocVisitor::visitPre(DocSection *s)
   if (m_hide) return;
   if (Config_getBool("PDF_HYPERLINKS"))
   {
-    m_t << "\\hypertarget{" << stripPath(s->file()) << "_" << s->anchor() << "}{}";
+    m_t << "\\hypertarget{" << s->file() << "_" << s->anchor() << "}{}";
   }
   m_t << "\\" << getSectionName(s->level()) << "{";
   filter(convertCharEntitiesToUTF8(s->title().data()));
-  m_t << "}\\label{" << stripPath(s->file()) << "_" << s->anchor() << "}" << endl;
+  m_t << "}\\label{" << s->file() << "_" << s->anchor() << "}" << endl;
 }
 
 void LatexDocVisitor::visitPost(DocSection *) 
@@ -871,7 +871,7 @@ void LatexDocVisitor::visitPost(DocHtmlDescList *dl)
 void LatexDocVisitor::visitPre(DocHtmlDescTitle *)
 {
   if (m_hide) return;
-  m_t << "\n\\item[";
+  m_t << "\n\\item[{";
   m_insideItem=TRUE;
 }
 
@@ -879,7 +879,7 @@ void LatexDocVisitor::visitPost(DocHtmlDescTitle *)
 {
   if (m_hide) return;
   m_insideItem=FALSE;
-  m_t << "]";
+  m_t << "}]";
 }
 
 void LatexDocVisitor::visitPre(DocHtmlDescData *)
@@ -1283,7 +1283,7 @@ void LatexDocVisitor::visitPre(DocSecRefItem *ref)
   static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
   if (pdfHyperlinks)
   {
-    m_t << "\\hyperlink{" << ref->file() << "_" << ref->anchor() << "}{" ;
+    m_t << "\\hyperref[" << ref->file() << "_" << ref->anchor() << "]{" ;
   }
 }
 
@@ -1387,7 +1387,7 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
                   parentType==DocParamSect::TemplateParam;
   if (!useTable)
   {
-    m_t << "\\item[";
+    m_t << "\\item[{";
   }
   if (sect && sect->hasInOutSpecifier())
   {
@@ -1456,7 +1456,7 @@ void LatexDocVisitor::visitPre(DocParamList *pl)
   }
   else
   {
-    m_t << "]";
+    m_t << "}]";
   }
 }
 
@@ -1487,10 +1487,10 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
   filter(x->title());
   m_t << "}" << endl;
   bool anonymousEnum = x->file()=="@";
-  m_t << "\\item[";
+  m_t << "\\item[{";
   if (Config_getBool("PDF_HYPERLINKS") && !anonymousEnum)
   {
-    m_t << "\\hyperlink{" << stripPath(x->file()) << "_" << x->anchor() << "}{";
+    m_t << "\\hyperref[" << x->file() << "_" << x->anchor() << "]{";
   }
   else
   {
@@ -1499,7 +1499,7 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
   m_insideItem=TRUE;
   filter(x->title());
   m_insideItem=FALSE;
-  m_t << "}]";
+  m_t << "}}]";
 }
 
 void LatexDocVisitor::visitPost(DocXRefItem *x)
@@ -1578,11 +1578,11 @@ void LatexDocVisitor::startLink(const QCString &ref,const QCString &file,const Q
 {
   if (ref.isEmpty() && Config_getBool("PDF_HYPERLINKS")) // internal PDF link 
   {
-    m_t << "\\hyperlink{";
-    if (!file.isEmpty()) m_t << stripPath(file);
+    m_t << "\\hyperref[";
+    if (!file.isEmpty()) m_t << file;
     if (!file.isEmpty() && !anchor.isEmpty()) m_t << "_";
     if (!anchor.isEmpty()) m_t << anchor;
-    m_t << "}{";
+    m_t << "]{";
   }
   else if (ref.isEmpty()) // internal non-PDF link
   {
diff --git a/src/latexgen.cpp b/src/latexgen.cpp
index 042dd7c..27bae52 100644
--- a/src/latexgen.cpp
+++ b/src/latexgen.cpp
@@ -1094,7 +1094,7 @@ void LatexGenerator::endIndexItem(const char *ref,const char *fn)
 {
   if (!ref && fn)
   {
-    t << "}{\\pageref{" << stripPath(fn) << "}}{}" << endl;
+    t << "}{\\pageref{" << fn << "}}{}" << endl;
   }
 }
 
@@ -1182,10 +1182,10 @@ void LatexGenerator::startTextLink(const char *f,const char *anchor)
 {
   if (!disableLinks && Config_getBool("PDF_HYPERLINKS"))
   {
-    t << "\\hyperlink{";
-    if (f) t << stripPath(f);
+    t << "\\hyperref[";
+    if (f) t << f;
     if (anchor) t << "_" << anchor; 
-    t << "}{";
+    t << "]{";
   }
   else
   {
@@ -1203,11 +1203,11 @@ void LatexGenerator::writeObjectLink(const char *ref, const char *f,
 {
   if (!disableLinks && !ref && Config_getBool("PDF_HYPERLINKS"))
   {
-    t << "\\hyperlink{";
-    if (f) t << stripPath(f);
+    t << "\\hyperref[";
+    if (f) t << f;
     if (f && anchor) t << "_"; 
     if (anchor) t << anchor; 
-    t << "}{";
+    t << "]{";
     docify(text);
     t << "}";
   }
@@ -1246,11 +1246,11 @@ void LatexGenerator::writeCodeLink(const char *ref,const char *f,
   }
   if (/*m_prettyCode &&*/ !disableLinks && !ref && usePDFLatex && pdfHyperlinks)
   {
-    t << "\\hyperlink{";
-    if (f) t << stripPath(f);
+    t << "\\hyperref[";
+    if (f) t << f;
     if (f && anchor) t << "_"; 
     if (anchor) t << anchor; 
-    t << "}{";
+    t << "]{";
     codify(name);
     t << "}";
   }
@@ -1267,7 +1267,7 @@ void LatexGenerator::startTitleHead(const char *fileName)
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   if (usePDFLatex && pdfHyperlinks && fileName)
   {
-    t << "\\hypertarget{" << stripPath(fileName) << "}{}";
+    t << "\\hypertarget{" << fileName << "}{}";
   }
   if (Config_getBool("COMPACT_LATEX")) 
   {
@@ -1284,7 +1284,7 @@ void LatexGenerator::endTitleHead(const char *fileName,const char *name)
   t << "}" << endl;
   if (name)
   {
-    t << "\\label{" << stripPath(fileName) << "}\\index{";
+    t << "\\label{" << fileName << "}\\index{";
     escapeLabelName(name);
     t << "@{";
     escapeMakeIndexChars(name);
@@ -1427,7 +1427,7 @@ void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
   if (usePDFLatex && pdfHyperlinks)
   {
     t << "\\hypertarget{";
-    if (fName) t << stripPath(fName);
+    if (fName) t << fName;
     if (anchor) t << "_" << anchor;
     t << "}{}";
   }
@@ -1436,7 +1436,7 @@ void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
 void LatexGenerator::endDoxyAnchor(const char *fName,const char *anchor)
 {
   t << "\\label{";
-  if (fName) t << stripPath(fName);
+  if (fName) t << fName;
   if (anchor) t << "_" << anchor;
   t << "}" << endl;
 }
@@ -1444,18 +1444,18 @@ void LatexGenerator::endDoxyAnchor(const char *fName,const char *anchor)
 void LatexGenerator::writeAnchor(const char *fName,const char *name)
 { 
   //printf("LatexGenerator::writeAnchor(%s,%s)\n",fName,name);
-  t << "\\label{" << stripPath(name) << "}" << endl; 
+  t << "\\label{" << name << "}" << endl; 
   static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   if (usePDFLatex && pdfHyperlinks)
   {
     if (fName)
     {
-      t << "\\hypertarget{" << stripPath(fName) << "_" << stripPath(name) << "}{}" << endl;
+      t << "\\hypertarget{" << fName << "_" << stripPath(name) << "}{}" << endl;
     }
     else
     {
-      t << "\\hypertarget{" << stripPath(name) << "}{}" << endl;
+      t << "\\hypertarget{" << name << "}{}" << endl;
     }
   }
 }
@@ -1494,7 +1494,7 @@ void LatexGenerator::startSection(const char *lab,const char *,SectionInfo::Sect
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   if (usePDFLatex && pdfHyperlinks)
   {
-    t << "\\hypertarget{" << stripPath(lab) << "}{}";
+    t << "\\hypertarget{" << lab << "}{}";
   }
   t << "\\";
   if (Config_getBool("COMPACT_LATEX"))
@@ -2103,7 +2103,7 @@ void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const
       //if (!m_prettyCode) return;
       if (usePDFLatex && pdfHyperlinks)
       {
-        t << "\\hypertarget{" << stripPath(lineAnchor) << "}{}";
+        t << "\\hypertarget{" << lineAnchor << "}{}";
       }
       writeCodeLink(ref,fileName,anchor,lineNumber,0);
     }
